phasespace package
====================

phasespace.phasespace module
--------------------------------

.. automodule:: phasespace.phasespace
    :members:
    :undoc-members:
    :show-inheritance:

phasespace.kinematics module
------------------------------

.. automodule:: phasespace.kinematics
    :members:
    :undoc-members:
    :show-inheritance:
